@@ -26,6 +26,8 @@
 #include "empathy-import-widget.h"
 
 #include <glib/gi18n-lib.h>
+#include <tp-account-widgets/tpaw-builder.h>
+#include <tp-account-widgets/tpaw-utils.h>
 
 #include "empathy-ui-utils.h"
 #include "empathy-utils.h"
@@ -60,7 +62,7 @@ typedef struct {
   GList *accounts;
   EmpathyImportApplication app_id;
 
-  EmpathyConnectionManagers *cms;
+  TpawConnectionManagers *cms;
 
   gboolean dispose_run;
 } EmpathyImportWidgetPriv;
@@ -169,7 +171,7 @@ import_widget_create_account_cb (GObject *source,
   if (tp_account_is_enabled (account))
     {
       account_manager = tp_account_manager_dup ();
-      empathy_connect_new_account (account, account_manager);
+      tpaw_connect_new_account (account, account_manager);
       g_object_unref (account_manager);
     }
 
@@ -430,14 +432,14 @@ do_constructed (GObject *obj)
   gchar *filename;
 
   filename = empathy_file_lookup ("empathy-import-dialog.ui", "src");
-  gui = empathy_builder_get_file (filename,
+  gui = tpaw_builder_get_file (filename,
       "widget_vbox", &priv->vbox,
       "treeview", &priv->treeview,
       "scrolledwindow", &priv->scrolledwindow,
       NULL);
 
   g_free (filename);
-  empathy_builder_unref_and_keep_widget (gui, priv->vbox);
+  tpaw_builder_unref_and_keep_widget (gui, priv->vbox);
 
   g_signal_connect (priv->vbox, "destroy",
       G_CALLBACK (import_widget_destroy_cb), self);
@@ -464,8 +466,8 @@ empathy_import_widget_class_init (EmpathyImportWidgetClass *klass)
   g_object_class_install_property (oclass, PROP_APPLICATION_ID, param_spec);
 
   param_spec = g_param_spec_object ("cms",
-      "EmpathyConnectionManagers", "EmpathyConnectionManager",
-      EMPATHY_TYPE_CONNECTION_MANAGERS,
+      "TpawConnectionManagers", "TpawConnectionManagers",
+      TPAW_TYPE_CONNECTION_MANAGERS,
       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_CONSTRUCT_ONLY);
   g_object_class_install_property (oclass, PROP_CMS, param_spec);
 
@@ -484,9 +486,9 @@ empathy_import_widget_init (EmpathyImportWidget *self)
 
 EmpathyImportWidget *
 empathy_import_widget_new (EmpathyImportApplication id,
-    EmpathyConnectionManagers *cms)
+    TpawConnectionManagers *cms)
 {
-  g_return_val_if_fail (EMPATHY_IS_CONNECTION_MANAGERS (cms), NULL);
+  g_return_val_if_fail (TPAW_IS_CONNECTION_MANAGERS (cms), NULL);
 
   return g_object_new (EMPATHY_TYPE_IMPORT_WIDGET,
       "application-id", id,
