@@ -489,6 +489,9 @@ tpaw_user_info_constructed (GObject *object)
 {
   TpawUserInfo *self = (TpawUserInfo *) object;
   GtkGrid *grid = (GtkGrid *) self;
+  GtkWidget *infobar;
+  GtkWidget *infobar_content;
+  GtkWidget *infobar_label;
   GtkWidget *title;
 
   G_OBJECT_CLASS (tpaw_user_info_parent_class)->constructed (object);
@@ -496,6 +499,19 @@ tpaw_user_info_constructed (GObject *object)
   gtk_grid_set_column_spacing (grid, 6);
   gtk_grid_set_row_spacing (grid, 6);
 
+  infobar = gtk_info_bar_new ();
+  g_object_set (infobar, "margin-bottom", 6, NULL);
+  gtk_info_bar_set_message_type (GTK_INFO_BAR (infobar), GTK_MESSAGE_INFO);
+  infobar_content = gtk_info_bar_get_content_area (GTK_INFO_BAR (infobar));
+  infobar_label = gtk_label_new (
+      _("These details will be shared with other users on this "
+        "chat network."));
+  gtk_container_add (GTK_CONTAINER (infobar_content), infobar_label);
+  gtk_widget_show (infobar_label);
+  gtk_grid_attach_next_to ((GtkGrid *) self, infobar, NULL,
+      GTK_POS_TOP, 3, 1);
+  gtk_widget_show (infobar);
+
   /* Setup id label */
   title = gtk_label_new (_("Identifier"));
   self->priv->identifier_label = gtk_label_new (
@@ -514,7 +530,8 @@ tpaw_user_info_constructed (GObject *object)
       G_CALLBACK (nickname_notify_cb), self, 0);
 
   /* Set up avatar chooser */
-  self->priv->avatar_chooser = tpaw_avatar_chooser_new (self->priv->account);
+  self->priv->avatar_chooser = tpaw_avatar_chooser_new (self->priv->account,
+      -1);
   gtk_grid_attach (grid, self->priv->avatar_chooser,
       2, 0, 1, 3);
   gtk_widget_show (self->priv->avatar_chooser);
